@@ -30,7 +30,7 @@ class GnomeDialog(_gtk.GtkWindow):
 		}
 		if attrs.has_key(attr):
 			return _obj2inst(attrs[attr](self._o))
-		raise AttributeError, attr
+		return _gtk.GtkWindow.__getattr__(self, attr)
 	def set_parent(self, parent):
 		_gnomeui.gnome_dialog_set_parent(self._o, parent._o)
 	def run(self):
@@ -197,6 +197,9 @@ class GnomeApp(_gtk.GtkWindow):
 		_gnomeui.gnome_app_set_toolbar(self._o, toolbar._o)
 	def set_statusbar(self, statusbar):
 		_gnomeui.gnome_app_set_statusbar(self._o, statusbar._o)
+	def set_statusbar_custom(self, container, statusbar):
+		_gnomeui.gnome_app_set_statusbar_custom(self._o, container._o,
+							statusbar._o)
 	def set_contents(self, contents):
 		_gnomeui.gnome_app_set_contents(self._o, contents._o)
 	def add_toolbar(self, toolbar, name, behavior, placement, band_num,
@@ -300,9 +303,12 @@ _gtk._name2cls['GnomeCalculator'] = GnomeCalculator
 
 class GnomeCanvas(_gtk.GtkLayout):
 	get_type = _gnomeui.gnome_canvas_get_type
-	def __init__(self, _obj=None):
+	def __init__(self, aa=_gtk.FALSE, _obj=None):
 		if _obj: self._o = _obj; return
-		self._o = _gnomeui.gnome_canvas_new()
+		if aa:
+			self._o = _gnomeui.gnome_canvas_new_aa()
+		else:
+			self._o = _gnomeui.gnome_canvas_new()
 	def root(self):
 		return GnomeCanvasGroup(
 			_obj=_gnomeui.gnome_canvas_root(self._o))
@@ -321,6 +327,9 @@ class GnomeCanvas(_gtk.GtkLayout):
 		return _gnomeui.gnome_canvas_get_scroll_offsets(self._o)
 	def update_now(self):
 		_gnomeui.gnome_canvas_update_now(self._o)
+	def get_item_at(self, x, y):
+		return _obj2inst(_gnomeui.gnome_canvas_get_item_at(self._o,
+								   x, y))
 	def request_redraw(self, x1,y1, x2,y2):
 		_gnomeui.gnome_canvas_request_redraw(self._o, x1,y1, x2,y2)
 	def w2c(self, wx, wy):
@@ -338,7 +347,7 @@ class GnomeCanvasItem(_gtk.GtkObject):
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 	def set(self, **args):
-		_fileprops(args)
+		_filtprops(args)
 		_gnomeui.gnome_canvas_item_set(self._o, args)
 	def move(self, dx, dy):
 		_gnomeui.gnome_canvas_item_move(self._o, dx, dy)
@@ -394,24 +403,22 @@ class GnomeCanvasGroup(GnomeCanvasItem):
 _gtk._name2cls['GnomeCanvasGroup'] = GnomeCanvasGroup
 
 class GnomeCanvasImage(GnomeCanvasItem):
-	"""has arguments image (unfortunately a pointer type - not useable yet)
-	'x', 'y', 'width', 'height', 'anchor'"""
+	"""has arguments 'image', 'x', 'y', 'width', 'height', 'anchor'"""
 	get_type = _gnomeui.gnome_canvas_image_get_type
 _gtk._name2cls['GnomeCanvasImage'] = GnomeCanvasItem
 
 class GnomeCanvasLine(GnomeCanvasItem):
-	"""has arguments 'points' (a point struct -- doh), 'fill_color',
-	'width_pixels', 'width_units', 'cap_style', 'join_style',
-	'first_arrowhead', 'last_arrowhead', 'smooth', 'spline_steps',
-	'arrow_shape_a', 'arrow_shape_b', 'arrow_shape_c'"""
+	"""has arguments 'points', 'fill_color', 'width_pixels',
+	'width_units', 'cap_style', 'join_style', 'first_arrowhead',
+	'last_arrowhead', 'smooth', 'spline_steps', 'arrow_shape_a',
+	'arrow_shape_b', 'arrow_shape_c'"""
 	get_type = _gnomeui.gnome_canvas_line_get_type
 _gtk._name2cls['GnomeCanvasLine'] = GnomeCanvasLine
 
 class GnomeCanvasPolygon(GnomeCanvasItem):
-	"""has argyments 'points' (GTK_TYPE_POINTER -- doh),
-	'fill_color', 'fill_color_gdk', 'outlint_color',
-	'outline_color_gdk', 'fill_stipple', 'outline_stipple',
-	'width_pixels', 'width_units'"""
+	"""has argyments 'points', 'fill_color', 'fill_color_gdk',
+	'outlint_color', 'outline_color_gdk', 'fill_stipple',
+	'outline_stipple', 'width_pixels', 'width_units'"""
 	get_type = _gnomeui.gnome_canvas_polygon_get_type
 _gtk._name2cls['GnomeCanvasPolygon'] = GnomeCanvasPolygon
 
@@ -485,6 +492,8 @@ class GnomeClient(_gtk.GtkObject):
 		_gnomeui.gnome_client_set_program(self._o, program)
 	def set_restart_style(self, style):
 		_gnomeui.gnome_client_set_restart_style(self._o, style)
+	def set_priority(self, priority):
+		_gnomeui.gnome_client_set_priority(self._o, priority)
 	def set_user_id(self, user_id):
 		_gnomeui.gnome_client_set_user_id(self._o, user_id)
 	def request_phase_2(self):
@@ -498,6 +507,8 @@ class GnomeClient(_gtk.GtkObject):
 						   fast, is_global)
 	def flush(self):
 		_gnomeui.gnome_client_flush(self._o)
+	def get_client_flags(self):
+		return _gnomeui.gnome_client_get_client_flags(self._o)
 _gtk._name2cls['GnomeClient'] = GnomeClient
 
 def interaction_key_return(key, cancel_shutdown):
@@ -536,10 +547,9 @@ _gtk._name2cls['GnomeColorPicker'] = GnomeColorPicker
 
 class GnomeDateEdit(_gtk.GtkHBox):
 	get_type = _gnomeui.gnome_date_edit_get_type
-	def __init__(self, the_time=0, show_time=0, use_24=0, _obj=None):
+	def __init__(self, the_time=0, flags=0, _obj=None):
 		if _obj: self._o = _obj; return
-		self._o = _gnomeui.gnome_date_edit_new(the_time, show_time,
-						       use_24)
+		self._o = _gnomeui.gnome_date_edit_new_flags(the_time, flags)
 	def set_time(self, the_time):
 		_gnomeui.gnome_date_edit_set_time(self._o, the_time)
 	def set_popup_range(self, low_hour, up_hour):
@@ -547,6 +557,10 @@ class GnomeDateEdit(_gtk.GtkHBox):
 							 up_hour)
 	def get_date(self):
 		return _gnomeui.gnome_date_edit_get_date(self._o)
+	def set_flags(self, flags):
+		_gnomeui.gnome_date_edit_set_flags(self._o, flags)
+	def get_flags(self):
+		return _gnomeui.gnome_date_edit_get_flags(self._o)
 _gtk._name2cls['GnomeDateEdit'] = GnomeDateEdit
 
 class GnomeDEntryEdit(_gtk.GtkObject):
@@ -574,6 +588,24 @@ class GnomeDEntryEdit(_gtk.GtkObject):
 		return _gnomeui.gnome_dentry_edit_get_icon(self._o)
 	def get_name(self):
 		return _gnomeui.gnome_dentry_edit_get_name(self._o)
+	def get_name_entry(self):
+		return _obj2inst(_gnomeui.gnome_dentry_edit_get_name_entry(
+			self._o))
+	def get_comment_entry(self):
+		return _obj2inst(_gnomeui.gnome_dentry_edit_get_comment_entry(
+			self._o))
+	def get_exec_entry(self):
+		return _obj2inst(_gnomeui.gnome_dentry_edit_get_exec_entry(
+			self._o))
+	def get_tryexec_entry(self):
+		return _obj2inst(_gnomeui.gnome_dentry_edit_get_tryexec_entry(
+			self._o))
+	def get_doc_entry(self):
+		return _obj2inst(_gnomeui.gnome_dentry_edit_get_doc_entry(
+			self._o))
+	def get_icon_entry(self):
+		return _obj2inst(_gnomeui.gnome_dentry_edit_get_icon_entry(
+			self._o))
 _gtk._name2cls['GnomeDEntryEdit'] = GnomeDEntryEdit
 
 class GnomeDockBand(_gtk.GtkContainer):
@@ -761,6 +793,8 @@ class GnomeIconEntry(_gtk.GtkVBox):
 							browse_dialog_title)
 	def set_pixmap_subdir(self, subdir):
 		_gnomeui.gnome_icon_entry_set_pixmap_subdir(self._o, subdir)
+	def set_icon(self, filename):
+		_gnomeui.gnome_icon_entry_set_icon(self._o, filename)
 	def gnome_file_entry(self):
 		return GnomeFileEntry(_obj=
 			_gnomeui.gnome_icon_entry_gnome_file_entry(self._o))
@@ -779,12 +813,9 @@ class GnomeIconList(GnomeCanvas):
 	def __init__(self, icon_width=70, adj=None,
 		     is_editable=_gtk.FALSE, _obj=None):
 		if _obj: self._o = _obj; return
-		if adj:
-			self._o = _gnomeui.gnome_icon_list_new(icon_width,
-							       adj._o,
-							       is_editable)
-		else:
-			self._o = _gnomeui.gnome_icon_list_new(icon_width)
+		if adj: adj = adj._o
+		self._o = _gnomeui.gnome_icon_list_new(icon_width, adj,
+						       is_editable)
 	def set_selection_mode(self, mode):
 		_gnomeui.gnome_icon_list_set_selection_mode(self._o, mode)
 	def append(self, icon_filename, text):
@@ -1050,6 +1081,14 @@ class GnomePaperSelector(_gtk.GtkVBox):
 		return _gnomeui.gnome_paper_selector_get_width(self._o)
 	def get_height(self):
 		return _gnomeui.gnome_paper_selector_get_height(self._o)
+	def get_left_margin(self):
+		return _gnomeui.gnome_paper_selector_get_left_margin(self._o)
+	def get_right_margin(self):
+		return _gnomeui.gnome_paper_selector_get_right_margin(self._o)
+	def get_top_margin(self):
+		return _gnomeui.gnome_paper_selector_get_top_margin(self._o)
+	def get_bottom_margin(self):
+		return _gnomeui.gnome_paper_selector_get_bottom_margin(self._o)
 _gtk._name2cls['GnomePaperSelector'] = GnomePaperSelector
 
 class GnomePixmap(_gtk.GtkWidget):
@@ -1137,7 +1176,10 @@ class GnomePropertyBox(GnomeDialog):
 	def changed(self, obj=None):
 		_gnomeui.gnome_property_box_changed(self._o)
 	def set_state(self, state):
-		_gnomeui.gnome_property_box_set_state(self._o, state)
+		print "GnomePropertyBox.set_state deprecated -- use set_modified"
+		self.set_modified(state)
+	def set_modified(self, modified):
+		_gnomeui.gnome_property_box_set_modified(self._o, modified)
 	def append_page(self, child, tab_label):
 		_gnomeui.gnome_property_box_append_page(self._o, child._o,
 							tab_label._o)
@@ -1240,10 +1282,8 @@ class GtkDial(_gtk.GtkWidget):
 	get_type = _gnomeui.gtk_dial_get_type
 	def __init__(self, adj=None, _obj=None):
 		if _obj: self._o = _obj; return
-		if adj:
-			self._o = _gnomeui.gtk_dial_new(adj._o)
-		else:
-			self._o = _gnomeui.gtk_dial_new()
+		if adj: adj = adj._o
+		self._o = _gnomeui.gtk_dial_new(adj)
 	def get_adjustment(self):
 		return _obj2inst(_gnomeui.gtk_dial_get_adjustment(self._o))
 	def set_update_policy(self, policy):
